# carleslibs

Carles Mateo's Python Libraries v. 1.0.5

https://blog.carlesmateo.com/carleslibs

Install with:

```pip install carleslibs```

It is shipped with a sample demo application to easily see how it works:

```carleslibs_demo.py```

**Packgades available:**

DateTimeUtils()

FileUtils()

KeyboardUtils()

MenuUtils()

PythonUtils()

StringUtils()

SubProcessUtils()

